'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var axios = _interopDefault(require('axios'));
var hash = _interopDefault(require('hash-object'));
var debounce = _interopDefault(require('lodash.debounce'));

/**
 * @param {string} url - URL that the API call is made to.
 * @param {object} config - Axios config object passed to the axios.request method.
 */
function useAPI(url, config = {}) {
  const [state, setState] = react.useState({
    response: undefined,
    error: undefined,
    isLoading: true
  });

  function updateState(stateUpdate) {
    setState({ ...state, ...stateUpdate });
  }

  const configHash = hash(config);

  react.useEffect(() => {
    updateState({ isLoading: true });
    axios(url, config)
      .then(response => {
        updateState({ error: undefined, response, isLoading: false });
      })
      .catch(error => {
        updateState({ error, response: undefined, isLoading: false });
      });
  }, [url, configHash]);

  const { response, error, isLoading } = state;
  const data = response ? response.data : undefined;
  return { data, response, error, isLoading };
}

function useParams(initialParams = {}, debounceDelay=500) {
  const [params, setParams] = react.useState(initialParams);
  const [isStale, setIsStale] = react.useState(false);

  function updateParams(updatedParams) {
    const newParams = { ...params, ...updatedParams };
    setParams(newParams);
  }

  const debouncedSetParams = react.useMemo(
    () =>
      debounce(newParams => {
        setIsStale(false);
        setParams(newParams);
      }, debounceDelay),
    []
  );

  return {
    params,
    isStale,
    setParams,
    debouncedSetParams: newParams => {
      setIsStale(true);
      debouncedSetParams(newParams);
    },
    updateParams,
    debouncedUpdateParams: updatedParams => {
      setIsStale(true);
      debouncedSetParams({ ...params, ...updatedParams });
    }
  };
}

function printMsg() {
  console.log('This is a message from the demo package');
}

exports.printMsg = printMsg;
exports.useAPI = useAPI;
exports.useParams = useParams;
